Learn R Programming

SSNbayes (version 0.0.3)

dist_weight_mat: Creates a list containing the stream distances and weights

Description

Creates a list containing the stream distances and weights

Usage

dist_weight_mat(path = path, net = 1, addfunccol = "addfunccol")

Value

A list of matrices

Arguments

path

Path to the files

net

(optional) A network from the SSN2 object

addfunccol

(optional) A parameter to compute the spatial weights

Examples

Run this code
# \donttest{
path <- system.file("extdata/clearwater.ssn", package = "SSNbayes")
mat_all <- dist_weight_mat(path, net = 2, addfunccol='afvArea')
# }

Run the code above in your browser using DataLab