Learn R Programming

SSNbayes (version 0.0.3)

dist_weight_mat_preds: Creates a list of distances and weights between observed and prediction sites

Description

The output matrices are symmetric except the hydrologic distance matrix D.

Usage

dist_weight_mat_preds(path = path, net = 1, addfunccol = "addfunccol")

Value

A list of matrices

Arguments

path

Path with the name of the SpatialStreamNetwork object

net

(optional) A network from the SpatialStreamNetwork object

addfunccol

(optional) A parameter to compute the spatial weights

Examples

Run this code
if (FALSE) {
path <- system.file("extdata/clearwater.ssn", package = "SSNbayes")
mat_all_pred <- dist_weight_mat_preds(path, net = 2, addfunccol='afvArea')}

Run the code above in your browser using DataLab